Module app

Module app 

Structs

App
The main application struct, will hold the state of the application.
SearchInput
The search input struct, used to store the search input value and the current index.

Enums

Action
InputMode
ListMode
Enum representing whether the system is currently showing a directory listing or paths from the database.