pub enum ListMode {
Directory,
Frecent,
}Expand description
Enum representing whether the system is currently showing a directory listing or paths from the database.
Variants
Directory
The system is currently showing a directory listing.
Frecent
The system is currently showing paths from the database that have been accessed frequently and recently.