pub struct App { /* private fields */ }Expand description
The main application struct, will hold the state of the application.
Implementations
Sourceimpl App
impl App
Sourcepub fn try_new(mode: ListMode, directory_index: DirectoryIndex) -> Result<Self>
pub fn try_new(mode: ListMode, directory_index: DirectoryIndex) -> Result<Self>
Tries to create a new instance of the application in a given list mode.
Sourcepub fn change_directory<T: AsRef<Path>>(&mut self, path: T) -> Result<()>
pub fn change_directory<T: AsRef<Path>>(&mut self, path: T) -> Result<()>
Changes the current directory and sorts the entries in the new directory.
pub fn change_to_frecent(&mut self) -> Result<()>
Sourcepub fn run<B: Backend>(&mut self, terminal: &mut Terminal<B>) -> Result<PathBuf>
pub fn run<B: Backend>(&mut self, terminal: &mut Terminal<B>) -> Result<PathBuf>
Runs the application’s main loop until the user quits.
Sourcepub fn handle_key_event(
&mut self,
key: KeyEvent,
modifiers: KeyModifiers,
) -> Result<()>
pub fn handle_key_event( &mut self, key: KeyEvent, modifiers: KeyModifiers, ) -> Result<()>
Handles a key event with the given key and modifiers, it will perform the appropriate action based on the current input mode and registered hotkeys.
pub fn get_sub_header_title(&self) -> String