Module entry

Module entry 

Structs

Entry
EntryList
EntryRenderData
This struct represents the data that will be used to render an entry in the list. It is used in conjunction with the search query to determine how to render the entry.

Enums

EntryKind