Module hotkeys

Module hotkeys 

Structs

HotkeysRegistry
HotkeysTrieNode
KeyCombo

Constants

PREFERRED_KEY_COMBOS_IN_ORDER
The preferred shortcuts for the entries in the list. These will be used to quickly jump to an entry and will be chosed based on the order that they appear in this array, this way we can prioritize ergonomics. In future versions, we might allow the user to customize these shortcuts.