Module index

Module index 

Structs

DirectoryIndex
A struct representing the directory index, which is a map of paths to their corresponding DirectoryIndexEntry objects. The index is stored on disk in a file specified by the user (or a default location see DEFAULT_INDEX_FILE_NAME).
DirectoryIndexEntry

Constants

DEFAULT_INDEX_FILE_NAME