Module app
tiny_dc
0.1.4
Module app
Module Items
Structs
Enums
In crate tiny_
dc
tiny_dc
Module
app
Structs

App
The main application struct, will hold the state of the application.
Search
Input
The search input struct, used to store the search input value and the current index.
Enums

Action
Input
Mode
List
Mode
Enum representing whether the system is currently showing a directory listing or paths from the database.