Module entry
tiny_dc
0.1.4
Module entry
Module Items
Structs
Enums
In crate tiny_
dc
tiny_dc
Module
entry
Structs

Entry
Entry
List
Entry
Render
Data
This struct represents the data that will be used to render an entry in the list. It is used in conjunction with the search query to determine how to render the entry.
Enums

Entry
Kind