Structs
- Directory
Index - A struct representing the directory index, which is a map of paths to their corresponding
DirectoryIndexEntryobjects. The index is stored on disk in a file specified by the user (or a default location seeDEFAULT_INDEX_FILE_NAME). - Directory
Index Entry