pub struct DirectoryIndex { /* private fields */ }Expand description
A struct representing the directory index, which is a map of paths to their corresponding
DirectoryIndexEntry objects. The index is stored on disk in a file specified by the user (or
a default location see DEFAULT_INDEX_FILE_NAME).
Implementations
Sourceimpl DirectoryIndex
impl DirectoryIndex
Sourcepub fn try_from(path: PathBuf) -> Result<Self>
pub fn try_from(path: PathBuf) -> Result<Self>
Reads the index from disk, if it doesn’t exist, creates a new one
Sourcepub fn push(&mut self, path: PathBuf) -> Result<()>
pub fn push(&mut self, path: PathBuf) -> Result<()>
Pushes a new path to the index and saves it to disk. If the path doesn’t exist it’s a no-op. If you push the same path multiple times, it will update the rank and last accessed time.
Sourcepub fn z(&mut self, queries: Vec<String>) -> Result<Option<PathBuf>>
pub fn z(&mut self, queries: Vec<String>) -> Result<Option<PathBuf>>
Finds the top-ranked directory matching the query.
If a non-existing path is found as a match, it will be removed from the index and the next match will be returned until the index is exhausted. The index will be updated if a removal occurs.
The inner workings of this algo was heavily inspured by `rupa/z: https://github.com/rupa/z
Sourcepub fn get_all_entries_ordered_by_rank(&self) -> Vec<PathBuf>
pub fn get_all_entries_ordered_by_rank(&self) -> Vec<PathBuf>
Returns all entries in the index ordered by their frecent score.